==> _private_core_network-0.0.40.tar.gz: lib/network_resources/model/the_movie_model_arckipel.dart <==

class TheMovieModelArckipel {
  int? bookMarkId;
  int? movieId;
  int? seen;
  MovieInfo? movie;

  TheMovieModelArckipel({this.bookMarkId, this.movieId, this.seen, this.movie});

  TheMovieModelArckipel.fromJson(Map<String, dynamic> json) {
    bookMarkId = json["bookMarkId"];
    movieId = json["movieId"];
    seen = json["seen"];
    movie = json["movie"] == null ? null : MovieInfo.fromJson(json["movie"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["bookMarkId"] = bookMarkId;
    _data["movieId"] = movieId;
    _data["seen"] = seen;
    if(movie != null) {
      _data["movie"] = movie?.toJson();
    }
    return _data;
  }

  TheMovieModelArckipel copyWith({
    int? bookMarkId,
    int? movieId,
    int? seen,
    MovieInfo? movie,
  }) => TheMovieModelArckipel(
    bookMarkId: bookMarkId ?? this.bookMarkId,
    movieId: movieId ?? this.movieId,
    seen: seen ?? this.seen,
    movie: movie ?? this.movie,
  );
}

class MovieInfo {
  int? id;
  String? title;
  int? year;
  String? producer;
  String? synopsys;
  String? thumbnailUrl;
  int? tmdbId;

  MovieInfo({this.id, this.title, this.year, this.producer, this.synopsys, this.thumbnailUrl, this.tmdbId});

  MovieInfo.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    title = json["title"];
    year = json["year"];
    producer = json["producer"];
    synopsys = json["synopsys"];
    thumbnailUrl = json["thumbnailUrl"];
    tmdbId = json["tmdbId"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["title"] = title;
    _data["year"] = year;
    _data["producer"] = producer;
    _data["synopsys"] = synopsys;
    _data["thumbnailUrl"] = thumbnailUrl;
    _data["tmdbId"] = tmdbId;
    return _data;
  }

  MovieInfo copyWith({
    int? id,
    String? title,
    int? year,
    String? producer,
    String? synopsys,
    String? thumbnailUrl,
    int? tmdbId,
  }) => MovieInfo(
    id: id ?? this.id,
    title: title ?? this.title,
    year: year ?? this.year,
    producer: producer ?? this.producer,
    synopsys: synopsys ?? this.synopsys,
    thumbnailUrl: thumbnailUrl ?? this.thumbnailUrl,
    tmdbId: tmdbId ?? this.tmdbId,
  );
}

==> _private_core_network-1.2.54.tar.gz: lib/network_resources/model/the_movie_model_arckipel.dart <==
class TheMovieModelArckipel {
  int? bookMarkId;
  int? movieId;
  int? seen;
  MovieInfo? movie;

  TheMovieModelArckipel({this.bookMarkId, this.movieId, this.seen, this.movie});

  TheMovieModelArckipel.fromJson(Map<String, dynamic> json) {
    bookMarkId = json["bookMarkId"];
    movieId = json["movieId"];
    seen = json["seen"];
    movie = json["movie"] == null ? null : MovieInfo.fromJson(json["movie"]);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["bookMarkId"] = bookMarkId;
    _data["movieId"] = movieId;
    _data["seen"] = seen;
    if (movie != null) {
      _data["movie"] = movie?.toJson();
    }
    return _data;
  }

  TheMovieModelArckipel copyWith({
    int? bookMarkId,
    int? movieId,
    int? seen,
    MovieInfo? movie,
  }) =>
      TheMovieModelArckipel(
        bookMarkId: bookMarkId ?? this.bookMarkId,
        movieId: movieId ?? this.movieId,
        seen: seen ?? this.seen,
        movie: movie ?? this.movie,
      );
}

class MovieInfo {
  int? id;
  String? title;
  int? year;
  String? producer;
  String? synopsys;
  String? thumbnailUrl;
  int? tmdbId;

  MovieInfo(
      {this.id,
      this.title,
      this.year,
      this.producer,
      this.synopsys,
      this.thumbnailUrl,
      this.tmdbId});

  MovieInfo.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    title = json["title"];
    year = json["year"];
    producer = json["producer"];
    synopsys = json["synopsys"];
    thumbnailUrl = json["thumbnailUrl"];
    tmdbId = json["tmdbId"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["title"] = title;
    _data["year"] = year;
    _data["producer"] = producer;
    _data["synopsys"] = synopsys;
    _data["thumbnailUrl"] = thumbnailUrl;
    _data["tmdbId"] = tmdbId;
    return _data;
  }

  MovieInfo copyWith({
    int? id,
    String? title,
    int? year,
    String? producer,
    String? synopsys,
    String? thumbnailUrl,
    int? tmdbId,
  }) =>
      MovieInfo(
        id: id ?? this.id,
        title: title ?? this.title,
        year: year ?? this.year,
        producer: producer ?? this.producer,
        synopsys: synopsys ?? this.synopsys,
        thumbnailUrl: thumbnailUrl ?? this.thumbnailUrl,
        tmdbId: tmdbId ?? this.tmdbId,
      );
}

class TmmAddToArckipelResult {
  int? movieId;
  int? seen;
  int? collectionId;

  TmmAddToArckipelResult(
      {this.movieId, this.seen, this.collectionId});

  TmmAddToArckipelResult.fromJson(Map<String, dynamic> json) {
    movieId = json["movieId"];
    seen = json["seen"];
    collectionId = json["collectionId"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["movieId"] = movieId;
    _data["seen"] = seen;
    _data["collectionId"] = collectionId;
    return _data;
  }

  TmmAddToArckipelResult copyWith({
    int? movieId,
    int? seen,
    int? collectionId,
  }) =>
      TmmAddToArckipelResult(
        movieId: movieId ?? this.movieId,
        seen: seen ?? this.seen,
        collectionId: collectionId ?? this.collectionId,
      );
}
